"""
Sample datasets for testing and examples.

This module provides sample datasets commonly used in community ecology
for testing and demonstrating the functionality of nuee.
"""

from .sample_data import (
    varespec,
    varechem,
    dune,
    dune_env,
    BCI,
    mite,
    mite_env,
)

__all__ = [
    "varespec",
    "varechem", 
    "dune",
    "dune_env",
    "BCI",
    "mite",
    "mite_env",
]